import { Component, OnInit } from "@angular/core";
import { Book, BooksService } from "./books.service";

@Component({
	selector: "books",
	templateUrl: "app/books.component.html"
})
export class BooksComponent implements OnInit {
	public books: Book[];
	public bookName: string;

	constructor(private booksSvc: BooksService) {
	}

	public ngOnInit() {
		this.refreshBooks();
	}

	private refreshBooks() {
		this.booksSvc.getBooks()
			.then(books => {
				this.books = books;
			});
	}

	public addBook() {
		if (this.bookName.trim() !== "") {
			let newBook = new Book();
			newBook.name = this.bookName;
			newBook.isRead = false;

			this.booksSvc.addBook(newBook)
				.then(() => {
					this.refreshBooks();
					this.bookName = "";
				});
		}
	}

	public markAsRead(book: Book) {
		this.booksSvc.markAsRead(book)
			.then(() => {
				this.refreshBooks();
			});
	}

	public delete(book: Book) {
		this.booksSvc.deleteBook(book)
			.then(() => {
				this.refreshBooks();
			});
	}
}
