import { Component, OnInit } from "@angular/core";
import {Response} from "@angular/http";
import {Observable} from "rxjs/observable";

import { BooksService } from "./books.service";
import { Book } from "./book.model";

@Component({
	selector: "books",
	templateUrl: "app/books.component.html"
})
export class BooksComponent implements OnInit {
	public books: Book[];
	private formModes = {
		add: "Add Book",
		edit: "Edit Book"
	};
	public submitText: string;
	public book: Book;

	constructor(private booksSvc: BooksService) {
		this.submitText = this.formModes.add;
		this.book = new Book();
	}

	public ngOnInit() {
		this.refreshBooks();
	}

	private refreshBooks() {
		this.booksSvc.getBooks().subscribe((response: Response) => {
			this.books = response.json();
		});
	}

	public addBook() {
		this.booksSvc.addBook(this.book).subscribe(() => {
			this.refreshBooks();
		});
	}

	public editBook(book: Book) {
		this.book = book;
		this.submitText = this.formModes.edit;
	}

	public submit() {
		let response: Observable<Response>;

		if (this.submitText === this.formModes.add) {
			response = this.booksSvc.addBook(this.book);
		}
		else if (this.submitText === this.formModes.edit) {
			response = this.booksSvc.editBook(this.book);
		}

		response.subscribe(() => {
			this.refreshBooks();
			this.submitText = this.formModes.add;
			this.book = new Book();
		});
	}

	public delete(bookId: number) {
		this.booksSvc.deleteBook(bookId)
			.subscribe(() => {
				this.refreshBooks();
			});
	}
}
