"use strict";

var koa = require("koa");
var serve = require("koa-static");
var route = require("koa-route");
var parse = require('co-body');

var livereload = require("livereload");
var fs = require("fs");

var app = koa();
var server = livereload.createServer();
server.watch(__dirname + "/app/*.js");
app.use(serve("."));

var books = JSON.parse(fs.readFileSync(__dirname + "/books.json", "utf8"));

function* allBooks(next) {
  if ("GET" != this.method) return yield next;

  this.body = yield books;
};

function* getBook(id, next) {
  if ("GET" != this.method) return yield next;
  var bookId = parseInt(id);

  this.body = yield books.filter((book) => book.id === bookId);
}

function* addBook(data, next) {
  if ("POST" !== this.method) return yield next;

  var newBook = JSON.parse(yield parse(this));

  var newBookId = books[books.length - 1].id + 1;
  newBook.id = newBookId;

  books.push(newBook);
  this.body = yield {};
}

function* editBook(id, next) {
  if ("PUT" != this.method) return yield next;

  var editedBook = JSON.parse(yield parse(this));
  var bookId = parseInt(id);

  for (let counter = 0; counter < books.length; counter++) {

    if (books[counter].id === bookId) {
      books[counter].name = editedBook.name;
      books[counter].author = editedBook.author;
      books[counter].price = editedBook.price;
      books[counter].publishedYear = editedBook.publishedYear;
      break;
    }
  }
  this.body = yield {};
}

function* deleteBook(id, next) {
  if ("DELETE" !== this.method) return yield next;

  var bookId = parseInt(id);

  var bookIndex = books.findIndex(book => book.id === bookId);

  books.splice(bookIndex, 1);

  this.body = yield {};
}

app.use(route.get("/api/books", allBooks));
app.use(route.get("/api/books/:id", getBook));
app.use(route.post("/api/books", addBook));
app.use(route.put("/api/books/:id", editBook));
app.use(route.delete("/api/books/:id", deleteBook));

app.listen(3000);
