import {Component,OnInit} from '@angular/core';
import { FormGroup,FormControl, FormBuilder,Validators } from '@angular/forms';
import {Employee} from './employee.model';
import {CustomValidator} from './validator';

@Component({
    selector: 'emp-data',
    templateUrl: './app/employee.html'
})

export class EmployeeComponent {
    form: FormGroup;
    emp: Employee;
    empNo: FormControl;
    empName: FormControl;
    salary: FormControl;
    deptName: FormControl;
    designation: FormControl;
    email: FormControl;

    employees: Employee[];
    helpLink: string;
    helpText: string;
    frmSubmitted: boolean;
    pattern: RegExp;

    constructor(fEmp: FormBuilder) {
        this.emp = new Employee(0, '', 0, '', '', '');

        this.employees = [];
        this.helpText = "Tax Rules";
        this.helpLink = "./app/taxhelper.html";
        this.frmSubmitted = false;
    }

    ngOnInit(){
        this.form = new FormGroup({
        'empNo': new FormControl(this.emp.empNo, Validators.compose([Validators.required, Validators.pattern('[0-9]+')])),
        'empName': new FormControl(this.emp.empName, Validators.compose([Validators.required, Validators.minLength(2),
         Validators.maxLength(16)])),
        'salary': new FormControl(this.emp.salary, Validators.compose([Validators.required, Validators.pattern('[0-9]+')])),
        'deptName': new FormControl(this.emp.deptName, Validators.compose([Validators.required,
         Validators.pattern('[A-Za-z]+')])),
        'designation': new FormControl(this.emp.designation, Validators.required),
        'email': new FormControl(this.emp.email, Validators.compose([Validators.required, CustomValidator.emailAddressValidator]))

        });
    }

    clear() {
        this.emp = new Employee(0, '', 0, '', '', '');
    }
    save() {
         if (this.emp.empName.length > 0 && this.emp.deptName.length > 0) {
            this.employees.push(this.emp);
            this.frmSubmitted = true;
        }
    }
    loadForm() {
        this.emp = new Employee(0, '', 0, '', '', '');
        this.frmSubmitted = false;
    }
    setDesignation() {
        if (this.emp.salary >= 1000 && this.emp.salary <= 12000) {
            this.emp.designation = "Jr. Programmer";
        }
        if (this.emp.salary > 12000 && this.emp.salary <= 30000) {
            this.emp.designation = "Lead";
        }

        if (this.emp.salary > 30000 && this.emp.salary <= 60000) {
            this.emp.designation = "Group Lead";
        }

        if (this.emp.salary > 60000) {
            this.emp.designation = "Manager";
        }
    }
}
