"use strict";

var koa = require("koa");
var serve = require("koa-static");
var route = require("koa-route");
var cors = require("koa-cors");
var parse = require('co-body');

var fs = require("fs");

var app = koa();
app.use(serve("."));
app.use(cors());

var books = JSON.parse(fs.readFileSync(__dirname + "/books.json", "utf8"));

function* allBooks(next) {
  if ("GET" != this.method) return yield next;

	this.body = yield books;
};

function* getBook(id, next) {
  if ("GET" != this.method) return yield next;
	var bookId = parseInt(id);

	this.body = yield books.filter((book) => book.id === bookId)[0];
}

function* addBook(data, next) {
	if ("POST" !== this.method) return yield next;

	var newBook = yield parse(this);

	var newBookId = books[books.length - 1].id + 1;
	newBook.id = newBookId;

	books.push(newBook);
	this.body = yield {};
}

function* addReview(id, next) {
	if ("POST" !== this.method) return yield next;

	var review = yield parse(this);
	var bookId = parseInt(id);

	var book = books.filter((book) => book.id === bookId)[0];
	book.reviews = book.reviews || [];
	book.reviews.push({
		reviewerName: review.reviewerName,
		rating: review.rating,
		comment: review.comment
	});

	this.body = yield {};
}

function* deleteBook(id, next) {
	if ("DELETE" !== this.method) return yield next;

	var bookId = parseInt(id);

	var bookIndex = books.findIndex(book => book.id === bookId);

	books.splice(bookIndex, 1);

	this.body = yield {};
}

app.use(route.get("/api/books", allBooks));
app.use(route.get("/api/books/:id", getBook));
app.use(route.post("/api/books", addBook));
app.use(route.delete("/api/books/:id", deleteBook));
app.use(route.post("/api/addreview/:id", addReview));

var readFileThunk = function (src) {
  return new Promise(function (resolve, reject) {
    fs.readFile(src, { 'encoding': 'utf8' }, function (err, data) {
      if (err) return reject(err);
      resolve(data);
    });
  });
}

app.listen(3001);
