import { Injectable } from '@angular/core';
import { Http, Response, Headers } from '@angular/http';
import { Router } from '@angular/router';

@Injectable()
export class LoginService {
  private accessToken: string;
  redirectUrl: string;

  constructor(private http: Http, private router: Router) {
    this.accessToken = localStorage.getItem("access_token");
  }

  get httpHeaders(): Headers {
    let headers: Headers = new Headers({ 'Authorization': `Bearer ${this.accessToken}` });
    return headers;
  }

  get isLoggedIn(): boolean {
    return !!this.accessToken;
  }

  login(username: string, password: string) {
    this.http.post('/login', {
      username,
      password
    }).subscribe((response: Response) => {
      this.accessToken = response.json().token;
      localStorage.setItem("access_token", this.accessToken);
      this.navigateToMainPage();
    });
  }

  logout() {
    this.accessToken = "";
    localStorage.removeItem("access_token");
    this.navigateToMainPage();
  }

  private navigateToMainPage() {
    this.router.navigate(['/']);
  }
}
