"use strict";

var koa = require("koa");
var serve = require("koa-static");
var route = require("koa-route");
var jwt = require("koa-jwt");
var parse = require('co-body');

var livereload = require("livereload");
var fs = require("fs");

var app = koa();
var server = livereload.createServer();
server.watch(__dirname + "/app/*.js");
app.use(serve("."));

var books = JSON.parse(fs.readFileSync(__dirname + "/books.json", "utf8"));
var secret = 'shared-secret';

function* login(next) {
  var claims = yield parse(this);

  if (claims.username === "Admin" && claims.password === "p@ssw0rd") {
    var token = jwt.sign(claims, secret);
    this.status = 200;
    this.body = { token: token };
  }
  else {
    this.status = 403;
    this.body = "Invalid credentials";
  }
}

function* allBooks(next) {
  if ("GET" != this.method) return yield next;

  this.body = yield books;
};

function* getBook(id, next) {
  if ("GET" != this.method) return yield next;
  var bookId = parseInt(id);

  this.body = yield books.filter((book) => book.id === bookId)[0];
}

function* addBook(data, next) {
  if ("POST" !== this.method) return yield next;

  var newBook = yield parse(this);

  var newBookId = books[books.length - 1].id + 1;
  newBook.id = newBookId;

  books.push(newBook);
  this.body = yield {};
}

function* addReview(id, next) {
  if ("POST" !== this.method) return yield next;

  var review = yield parse(this);
  var bookId = parseInt(id);

  var book = books.filter((book) => book.id === bookId)[0];
  book.reviews.push({
    reviewerName: review.reviewerName,
    rating: review.rating,
    comment: review.comment
  });

  this.body = yield {};
}

function* deleteBook(id, next) {
  if ("DELETE" !== this.method) return yield next;

  var bookId = parseInt(id);

  var bookIndex = books.findIndex(book => book.id === bookId);

  books.splice(bookIndex, 1);

  this.body = yield {};
}

app.use(route.post("/login", login));
app.use(route.get("/api/books", allBooks));
app.use(route.get("/api/books/:id", getBook));

// Everything behind this will be protected.
app.use(jwt({
  secret
}).unless({ method: "GET" }));

app.use(route.post("/api/books", addBook));
app.use(route.delete("/api/books/:id", deleteBook));
app.use(route.post("/api/addreview/:id", addReview));

var readFileThunk = function (src) {
  return new Promise(function (resolve, reject) {
    fs.readFile(src, { 'encoding': 'utf8' }, function (err, data) {
      if (err) return reject(err);
      resolve(data);
    });
  });
}

app.use(route.get('/*', function* () {
  this.body = yield readFileThunk(__dirname + '/index.html');
}));

app.listen(3000);
